@@ -52,8 +52,8 @@ class Encashment(QuickRestoObject):
         return self._kkm
 
     @property
-    def _sale_place(self) -> SalePlace:
-        return self.__sale_place
+    def sale_place(self) -> SalePlace:
+        return self._sale_place
 
     @property
     def shift(self) -> Shift:
